# encoding: utf-8
import sys
sys.path.insert(0, 'awesome_print')

import unittest
from awesome_print import format

class Test_awesome_print(unittest.TestCase):

    def test_None(self):
        self.assertEqual(format(None), '\x1b[0;31mNone\x1b[0m')

    def test_True(self):
        self.assertEqual(format(True), '\x1b[1;32mTrue\x1b[0m')

    def test_False(self):
        self.assertEqual(format(False), '\x1b[1;32mFalse\x1b[0m')

    def test_String_plain(self):
        self.assertEqual(format('plain string'), '\x1b[0;33mplain string\x1b[0m')

    def test_String_with_escapes(self):
        self.assertEqual(format("with\n's"), '\x1b[0;33mwith\n\'s\x1b[0m')

    def test_Int_positive(self):
        self.assertEqual(format(12345), '\x1b[1;34m12345\x1b[0m')

    def test_Int_negative(self):
        self.assertEqual(format(-12345), '\x1b[1;34m-12345\x1b[0m')

    def test_Long_positive(self):
        self.assertEqual(format(12345l), '\x1b[1;34m12345\x1b[0m')

    def test_Long_negative(self):
        self.assertEqual(format(-12345l), '\x1b[1;34m-12345\x1b[0m')

    def test_Float_positive(self):
        self.assertEqual(format(123.45), '\x1b[1;34m123.45\x1b[0m')

    def test_Float_negative(self):
        self.assertEqual(format(-123.45), '\x1b[1;34m-123.45\x1b[0m')

    def test_Complex_positive(self):
        self.assertEqual(format(complex('1.2+3.45j')),
                '\x1b[1;34m(1.2+3.45j)\x1b[0m')

    def test_Complex_negative(self):
        self.assertEqual(format(complex('-1.2+3.45j')),
                '\x1b[1;34m(-1.2+3.45j)\x1b[0m')

    def test_Tuple_empty(self):
        self.assertEqual(format(()), '()')

    def test_Tuple_Int(self):
        self.assertEqual(format((1,)), '(\n  [0] \x1b[1;34m1\x1b[0m\n)')

    def test_Tuple_mixed(self):
        self.assertEqual(format((1,True,'string')),
            '(\n' +
            '  [0] \x1b[1;34m1\x1b[0m,\n' +
            '  [1] \x1b[1;32mTrue\x1b[0m,\n' +
            '  [2] \x1b[0;33mstring\x1b[0m\n' +
            ')')

    def test_List_empty(self):
        self.assertEqual(format([]), '[]')

    def test_List_Int(self):
        self.assertEqual(format([1]), '[\n  [0] \x1b[1;34m1\x1b[0m\n]')

    def test_List_mixed(self):
        self.assertEqual(format([1,True,'string']),
            '[\n' +
            '  [0] \x1b[1;34m1\x1b[0m,\n' +
            '  [1] \x1b[1;32mTrue\x1b[0m,\n' +
            '  [2] \x1b[0;33mstring\x1b[0m\n' +
            ']')

    def test_Dict_empty(self):
        self.assertEqual(format({}), '{}')

    def test_Dict_Int(self):
        self.assertEqual(format({1:2}),
                '{\n  \x1b[1;34m1\x1b[0m: \x1b[1;34m2\x1b[0m\n}')

    def test_Dict_mixed(self):
        self.assertEqual(format({None:False,'key':'value',2:5}),
                '{\n' +
                '  \x1b[0;31mNone\x1b[0m: \x1b[1;32mFalse\x1b[0m,\n' +
                '     \x1b[1;34m2\x1b[0m: \x1b[1;34m5\x1b[0m,\n' +
                '   \x1b[0;33mkey\x1b[0m: \x1b[0;33mvalue\x1b[0m\n' +
                '}')

    def test_List_in_List(self):
        self.assertEqual(format(
            [
                [1,2,3],
            ]),
            '[\n' +
            '  [0] [\n' +
            '    [0] \x1b[1;34m1\x1b[0m,\n' +
            '    [1] \x1b[1;34m2\x1b[0m,\n' +
            '    [2] \x1b[1;34m3\x1b[0m\n' +
            '  ]\n' +
            ']'
            )

    def test_Dict_in_List(self):
        self.assertEqual(format(
            [
                {
                    'a': 'b'
                }
            ]),
            '[\n' +
            '  [0] {\n' +
            '    \x1b[0;33ma\x1b[0m: \x1b[0;33mb\x1b[0m\n' +
            '  }\n' +
            ']'
            )


if __name__ == '__main__':
    unittest.main()



""" Attempt to clone https://github.com/michaeldv/awesome_print

Usage:
    from awesome_print import ap
    ap(object)
"""
import __builtin__
from types import *

mode = 'ansi'

def ap(*args):
    for arg in args:
        print format(arg)

def indent(level):
    return '  ' * level

def format(obj, level = 0):
    type = __builtin__.type(obj)

    if type is NoneType:
        return red('None')

    if type is TypeType:
        pass

    if type is BooleanType:
        return green(str(obj))

    if type in [StringType, UnicodeType]:
        return yellow(str(obj))

    if type in [IntType, LongType, FloatType, ComplexType]:
        return bold_blue(str(obj))

    if type in (TupleType, ListType):
        open, close = ('(', ')') if type is TupleType else ('[', ']')
        if len(obj) is 0:
            return open + close

        s = []
        i = 0
        width = str(len(str(len(obj))))
        for e in obj:
            s.append(('%s[%' + width + 'd] %s') % \
                    (indent(level + 1), i, format(e, level + 1)))
            i+=1

        return open + "\n" + \
                        ",\n".join(s) + \
               "\n" + indent(level) + close

    if type is DictType:
        if len(obj) is 0:
            return '{}'

        width = str(max([flen(format(k)) for k in obj.keys()]))
        s = []
        for k in obj.keys():
            v = obj[k]
            s.append(('%s%' + width + 's: %s') % \
                    (indent(level + 1), format(k), format(v, level + 1)))

        return '{' + "\n" + \
                        ",\n".join(s) + \
               "\n" + indent(level) + '}'

    if type is LambdaType:
        return str(obj)

    return str(obj)

def flen(str):
    return max(len(s) for s in str.split("\n"))

def black(str):
    return color(str, '30')

def dark_gray(str):
    return bold(str, '30')

def red(str):
    return color(str, '31')

def bold_red(str):
    return bold(str, '31')

def green(str):
    return color(str, '32')

def green(str):
    return bold(str, '32')

def yellow(str):
    return color(str, '33')

def bold_yellow(str):
    return bold(str, '33')

def blue(str):
    return color(str, '34')

def bold_blue(str):
    return bold(str, '34')

def purple(str):
    return color(str, '35')

def bold_purple(str):
    return bold(str, '35')

def cyan(str):
    return color(str, '36')

def bold_cyan(str):
    return bold(str, '36')

def light_gray(str):
    return color(str, '37')

def white(str):
    return bold(str, '37')

def color(str, color, intensity='0'):
    if mode == 'plain':
    	return str
    return '\033['+intensity+';'+color+'m'+str+'\033[0m'

def bold(str, col):
    if mode == 'plain':
    	return str
    return color(str, col, '1')



from distutils.core import setup

setup(
    name='awesome_print',
    version='0.1.1',
    author='Stan Mazhara',
    author_email='akmegran@gmail.com',
    packages=['awesome_print', 'awesome_print.test'],
    license='LICENSE',
    description='Awesome print.',
    long_description=open('README.txt').read(),
    url='https://github.com/smazhara/awesome_print',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Console',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: POSIX',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Utilities'
        ]
)
